/*
 * libleaftag-gtk/tag-list.h - A widget which keeps a list of tags, shown as
 *                             GtkToggleButtons, with reflowing
 *                             height-for-width sizing.
 *
 * Copyright (C) 2006 David Trowbridge
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 *
 */
#ifndef _LEAFTAG_GTK_TAG_LIST_H_
#define _LEAFTAG_GTK_TAG_LIST_H_

typedef struct _LeaftagGtkTagList      LeaftagGtkTagList;
typedef struct _LeaftagGtkTagListClass LeaftagGtkTagListClass;
typedef struct _LeaftagGtkTagListPriv  LeaftagGtkTagListPriv;

#include <gtk/gtkvbox.h>

#define LEAFTAG_GTK_TYPE_TAG_LIST            (leaftag_gtk_tag_list_get_type())
#define LEAFTAG_GTK_TAG_LIST(obj)            (G_TYPE_CHECK_INSTANCE_CAST((obj), LEAFTAG_GTK_TYPE_TAG_LIST, LeaftagGtkTagList))
#define LEAFTAG_GTK_TAG_LIST_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST((klass), LEAFTAG_GTK_TYPE_TAG_LIST, LeaftagGtkTagListClass))
#define LEAFTAG_GTK_IS_TAG_LIST(obj)         (G_TYPE_CHECK_INSTANCE_TYPE((obj), LEAFTAG_GTK_TYPE_TAG_LIST))
#define LEAFTAG_GTK_IS_TAG_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass), LEAFTAG_GTK_TYPE_TAG_LIST))
#define LEAFTAG_GTK_TAG_LIST_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj), LEAFTAG_GTK_TYPE_TAG_LIST, LeaftagGtkTagListClass))

struct _LeaftagGtkTagList
{
	GtkVBox parent;

	LeaftagGtkTagListPriv *priv;
};

struct _LeaftagGtkTagListClass
{
	GtkVBoxClass parent_class;

	/* Signals */
	void (*tag_activated)   (LeaftagGtkTagList *list, const gchar *tag);
	void (*tag_deactivated) (LeaftagGtkTagList *list, const gchar *tag);
};

G_BEGIN_DECLS

GType      leaftag_gtk_tag_list_get_type         (void);
GtkWidget *leaftag_gtk_tag_list_new              (void);
void       leaftag_gtk_tag_list_add_tag          (LeaftagGtkTagList *list,
                                                  const gchar       *tag);
void       leaftag_gtk_tag_list_remove_tag       (LeaftagGtkTagList *list,
                                                  const gchar       *tag);
void       leaftag_gtk_tag_list_set_active       (LeaftagGtkTagList *list,
                                                  const gchar       *tag);
void       leaftag_gtk_tag_list_set_inactive     (LeaftagGtkTagList *list,
                                                  const gchar       *tag);
void       leaftag_gtk_tag_list_set_inconsistent (LeaftagGtkTagList *list,
                                                  const gchar       *tag);
void       leaftag_gtk_tag_list_freeze           (LeaftagGtkTagList *list);
void       leaftag_gtk_tag_list_thaw             (LeaftagGtkTagList *list);

G_END_DECLS

#endif
